#
# spec file for package python-quimb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-quimb
Version:        1.4.2
Release:        4.1
Summary:        Python library for quantum information and many-body calculations
License:        Apache-2.0
URL:            https://quimb.readthedocs.io/
Source:         https://github.com/jcmgray/quimb/archive/%{version}.tar.gz#/quimb-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cytoolz >= 0.8.0
Requires:       python-numba >= 0.39
Requires:       python-numpy >= 1.17
Requires:       python-opt-einsum >= 3.2
Requires:       python-psutil >= 4.3.1
Requires:       python-scipy >= 1.0.0
Requires:       python-tqdm >= 4
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-autoray >= 0.5.1
Recommends:     python-diskcache >= 3.0
Recommends:     python-matplotlib >= 2
Recommends:     python-networkx
Suggests:       python-mpi4py
Suggests:       python-petsc4py
Suggests:       python-randomgen >= 1.18
Suggests:       python-slepc4py
# This package does not support 32 bit arch, s390x fails too
ExcludeArch:    %{ix86} %{arm} ppc s390x
# SECTION test
# extra
BuildRequires:  %{python_module autoray >= 0.5.1}
# runtime
BuildRequires:  %{python_module cytoolz >= 0.8.0}
BuildRequires:  %{python_module diskcache >= 3.0}
BuildRequires:  %{python_module matplotlib >= 2}
BuildRequires:  %{python_module networkx >= 2.3}
BuildRequires:  %{python_module numba >= 0.39}
BuildRequires:  %{python_module numpy >= 1.17}
BuildRequires:  %{python_module opt-einsum >= 3.2}
BuildRequires:  %{python_module psutil >= 4.3.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 1.0.0}
BuildRequires:  %{python_module tqdm >= 4}
# /SECTION
%python_subpackages

%description
quimb is an easy but fast python library for quantum information and
many-body calculations, including with tensor networks.

%prep
%setup -q -n quimb-%{version}
sed -i '/addopts/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/quimb-mpi-python
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative quimb-mpi-python

%postun
%python_uninstall_alternative quimb-mpi-python

%check
# precision comparison slightly out of tolerance
%pytest -k "not (test_subtract_update and float32)"

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/quimb-mpi-python
%{python_sitelib}/quimb-%{version}.dist-info
%{python_sitelib}/quimb

%changelog
* Thu Jun  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Numba now exists for Python 3.11, stop skipping it.
* Thu Mar 23 2023 Ben Greiner <code@bnavigator.de>
- Skip python311: no numba yet
* Thu Feb  2 2023 Dirk Müller <dmueller@suse.com>
- upgrade opt-einsum to requires as it is imported by tensor/
  unconditionally
* Sat Jan 14 2023 Ben Greiner <code@bnavigator.de>
- Update to v1.4.2
  * no relevant code changes for openSUSE users
- Release v1.4.1
  [#]# Enhancements
  * unify much functionality from 1D, 2D and 3D into general
    arbitrary geometry class
    quimb.tensor.tensor_arbgeom.TensorNetworkGen
  * refactor contraction, allowing using cotengra directly
  * add visualize() for visualizing the actual data entries of an
    arbitrarily high dimensional tensor
  * add Gate class for more robust tracking and manipulation of
    gates in quantum Circuit simulation
  * tweak TN drawing style and layout
  * tweak default gauging options of compressed contraction
  * add compute_hierarchical_grouping()
  * add as_network()
  * add inds_size()
  * add get_hyperinds()
  * add outer_size()
  * improve group_inds()
  * refactor tensor decompositiona and ‘isometrization’ methods
  * begin supporting pytree specifications in TNOptimizer, e.g. for
    constants
  * add experimental submodule for new sharing features
  * register tensor and tensor network objects with jax pytree
    interface (PR150)
  * update CI infrastructure
  [#]# Bug fixes:
  * fix force atlas 2 and weight_attr bug (GH126)
  * allow unpickling of PTensor objects (GH128, PR131)
- Release v1.4.0
  [#]# Enhancements
  * Add 2D tensor network support and algorithms
  * Add 3D tensor network infrastructure
  * Add arbitrary geometry quantum state infrastructure
  * Many changes to TNOptimizer
  * Many changes to TN drawing
  * Many changes to Circuit simulation
  * Many improvements to TN simplification
  * Make all tag and index operations deterministic
  * Add tensor_network_sum(), tensor_network_distance() and fit()
  * Various memory and performance improvements
  * Various graph generators and TN builders
* Fri Feb  5 2021 Benjamin Greiner <code@bnavigator.de>
- Generalize the ExcludeArch into %%ix64 %%arm ppc s390x
* Thu Feb  4 2021 Benjamin Greiner <code@bnavigator.de>
- Disable build for armv7l and s390x
* Tue Jan 19 2021 andy great <andythe_great@pm.me>
- Disable build for python36 because scipy.
* Sat Aug 22 2020 andy great <andythe_great@pm.me>
- Clean up spec file.
* Wed Aug 19 2020 andy great <andythe_great@pm.me>
- Remove noarch macro from spec file.
* Wed Aug 19 2020 andy great <andythe_great@pm.me>
- Disable build for 32-bit arch because numba and parallel does not
  support 32-bit arch. Tried to export variable
  "export QUIMB_NUMBA_PARALLEL=off" does not solve the issue.
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Initial package release.
